==> gutsypackage-1.0.7.tgz: package/Package.js <==
const { Enum } = require("./Enum/Enum")
const { StringMax } = require("./Validator/StringMax")
const { IsDaylightSavingTime } = require("./Utils/Date/DayLightSaving")
const { IsoDateString } = require("./Utils/Date/IsoDateString")
const { DayName, MonthSlashDate,  TwelvehourString} = require("./Utils/Date/Text")
const { IsoDateString2UTC, Now2UTC} = require("./Utils/Date/UTC")
const { 
  UniversityDB, UniversityTestDB, GetUniversityLogoKey, GetUniversityName, HasUniversity
} = require("./StaticDB/UniversityDB")
const { IsEmail, IsEmailDomainAllowed} = require("./Validator/General/EmailValidator")
const { IsCourseSubject } = require("./Validator/AcademicMatch/CourseSubjectValidator")
const { IsRole } = require("./Validator/AcademicMatch/RoleValidator")
const DateValidator = require("./Validator/AcademicMatch/DateValidator")
const { IsAffliation } = require("./Validator/Language/AffliationValidator")
const { IsLanguageMatchStatus } = require("./Validator/Language/LanguageMatchStatusValidator")
const { IsLanguage } = require("./Validator/Language/LanguageValidator")
const { IsName } = require("./Validator/User/NameValidator")
const { IsPassword } = require("./Validator/User/PasswordValidator")

module.exports = {
  Enum,
  StringMax,
  IsEmail, IsEmailDomainAllowed,
  DateValidator,
  IsCourseSubject,
  IsRole,
  IsDaylightSavingTime,
  IsoDateString,
  DayName, MonthSlashDate, TwelvehourString,
  IsoDateString2UTC, Now2UTC,

  IsAffliation, IsLanguageMatchStatus, IsLanguage,

  IsName, IsPassword,

  UniversityDB, UniversityTestDB, GetUniversityLogoKey, GetUniversityName, HasUniversity
}

==> gutsypackage-1.0.11.tgz: package/Package.js <==
const { Enum } = require("./Enum/Enum")
const { StringMax } = require("./Validator/StringMax")
const { IsDaylightSavingTime } = require("./Utils/Date/DayLightSaving")
const { IsoDateString } = require("./Utils/Date/IsoDateString")
const { DayName, MonthSlashDate,  TwelvehourString} = require("./Utils/Date/Text")
const { IsoDateString2UTC, Now2UTC} = require("./Utils/Date/UTC")
const { UniversityDB, UniversityTestDB} = require("./StaticDB/UniversityDB")
const {
  GetUniversityLogoKey, GetUniversityName, GetUniversityTimeZoneHourOffset, HasUniversity
} = require("./StaticDB/UniversityDbUtil")
const { IsEmail, IsEmailDomainAllowed} = require("./Validator/General/EmailValidator")
const { IsCourseSubject } = require("./Validator/AcademicMatch/CourseSubjectValidator")
const { IsRole } = require("./Validator/AcademicMatch/RoleValidator")
const DateValidator = require("./Validator/AcademicMatch/DateValidator")
const { IsAffliation } = require("./Validator/Language/AffliationValidator")
const { IsLanguageMatchStatus } = require("./Validator/Language/LanguageMatchStatusValidator")
const { IsLanguage } = require("./Validator/Language/LanguageValidator")
const { IsName } = require("./Validator/User/NameValidator")
const { IsPassword } = require("./Validator/User/PasswordValidator")

module.exports = {
  Enum,
  StringMax,
  IsEmail, IsEmailDomainAllowed,
  DateValidator,
  IsCourseSubject,
  IsRole,
  IsDaylightSavingTime,
  IsoDateString,
  DayName, MonthSlashDate, TwelvehourString,
  IsoDateString2UTC, Now2UTC,

  IsAffliation, IsLanguageMatchStatus, IsLanguage,

  IsName, IsPassword,

  UniversityDB, UniversityTestDB, 
  GetUniversityLogoKey, GetUniversityName,GetUniversityTimeZoneHourOffset, HasUniversity
}
